set_colors: Set column col for event colors and column fontcol for label colors
Description
Set column col for event colors and column fontcol for label colors
Usage
set_colors(data, eventcolor_column, fontcolor_column)
Arguments
data
the data frame containing event data
eventcolor_column
name of the event color column
fontcolor_column
name of the lable color column
Value
same data frame as input, but with columns col and fontcol filled with color codes or names.