powered by
Instead of naive "always increment by 1" approach, we are using a more sophisticated method to use plot space efficiently
set_y_values(data)
the data frame with data to be distributed, has to have start, end and subplot column
start
end
subplot
the data frame enriched with numeric y column
y
# NOT RUN { set_y_values(data.frame( event = 1:4, start = c("2019-01-01", "2019-01-10"), end = c("2019-01-01", "2019-01-10"), subplot = 1 ), stringsAsFactors = F) # }
Run the code above in your browser using DataLab